==> ah-form-builder-sample-0.6.19.tgz: package/es/components/toolbar/Drawer.js <==
var _jsxFileName = "/var/apps/ah-form-builder/src/components/toolbar/Drawer.js";
import React, { useEffect } from 'react';
import { makeStyles } from '@material-ui/core/styles';
import Drawer from '@material-ui/core/Drawer';
import AppBar from '@material-ui/core/AppBar';
import Toolbar from '@material-ui/core/Toolbar';
import Typography from '@material-ui/core/Typography';
import Divider from '@material-ui/core/Divider';
import Paper from '@material-ui/core/Paper';
var useStyles = makeStyles(function (theme) {
  return {
    titleCenter: {
      flexGrow: 1,
      textAlign: 'center'
    },
    titleWithAction: {
      flexGrow: 1
    },
    drawerPaper: {
      width: '32%'
    }
  };
});
export default function PersistentDrawerRight(props) {
  var classes = useStyles();
  useEffect(function () {
    window.onscroll = function () {
      fixToolbar();
    };
  });

  var fixToolbar = function fixToolbar() {
    var header = document.getElementById("toolbar-main");
    var sticky = header.offsetTop;

    if (window.pageYOffset > sticky) {
      header.classList.add("sticky");
    } else {
      header.classList.remove("sticky");
    }
  };

  return /*#__PURE__*/React.createElement("div", {
    className: "toolbar-main",
    id: "toolbar-main",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 41,
      columnNumber: 5
    }
  }, /*#__PURE__*/React.createElement(AppBar, {
    className: "position-static",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 42,
      columnNumber: 7
    }
  }, /*#__PURE__*/React.createElement(Toolbar, {
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 43,
      columnNumber: 9
    }
  }, /*#__PURE__*/React.createElement(Typography, {
    variant: "h6",
    noWrap: true,
    className: !!props.rightIcon ? classes.titleWithAction : classes.titleCenter + " toolBarTitle",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 44,
      columnNumber: 11
    }
  }, props.title, !!props.rightIcon ? /*#__PURE__*/React.createElement("span", {
    className: "pull-right cursor-pointer",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 47,
      columnNumber: 15
    }
  }, props.rightIcon) : ""))), /*#__PURE__*/React.createElement(Divider, {
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 52,
      columnNumber: 7
    }
  }), /*#__PURE__*/React.createElement("div", {
    className: props.type === 'fields' ? "toolbar-inner-paper toolbar-field-types" : "toolbar-inner-paper",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 53,
      columnNumber: 7
    }
  }, props.children));
}

==> ah-form-builder-sample-0.6.86.tgz: package/es/components/toolbar/Drawer.js <==
var _jsxFileName = "/var/www/html/formbuilder/src/components/toolbar/Drawer.js";
import React, { useEffect } from 'react';
import { makeStyles } from '@material-ui/core/styles';
import AppBar from '@material-ui/core/AppBar';
import Toolbar from '@material-ui/core/Toolbar';
import Typography from '@material-ui/core/Typography';
import Divider from '@material-ui/core/Divider';
var useStyles = makeStyles(function (theme) {
  return {
    titleCenter: {
      flexGrow: 1,
      textAlign: 'center'
    },
    titleWithAction: {
      flexGrow: 1
    },
    drawerPaper: {
      width: '32%'
    }
  };
});
export default function PersistentDrawerRight(props) {
  var classes = useStyles();
  useEffect(function () {
    window.onscroll = function () {
      fixToolbar();
    };
  });

  var fixToolbar = function fixToolbar() {
    var header = document.getElementById("toolbar-main");
    var sticky = header.offsetTop;

    if (window.pageYOffset > sticky) {
      header.classList.add("sticky");
    } else {
      header.classList.remove("sticky");
    }
  };

  return /*#__PURE__*/React.createElement("div", {
    className: "ahfb-toolbar-main",
    id: "toolbar-main",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 39,
      columnNumber: 5
    }
  }, /*#__PURE__*/React.createElement(AppBar, {
    className: "ahfb-position-static",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 40,
      columnNumber: 7
    }
  }, /*#__PURE__*/React.createElement(Toolbar, {
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 41,
      columnNumber: 9
    }
  }, /*#__PURE__*/React.createElement(Typography, {
    variant: "h6",
    noWrap: true,
    className: !!props.rightIcon ? classes.titleWithAction : classes.titleCenter + " toolBarTitle",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 42,
      columnNumber: 11
    }
  }, props.title, !!props.rightIcon ? /*#__PURE__*/React.createElement("span", {
    className: "ahfb-pull-right ahfb-cursor-pointer",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 45,
      columnNumber: 15
    }
  }, props.rightIcon) : ""))), /*#__PURE__*/React.createElement(Divider, {
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 50,
      columnNumber: 7
    }
  }), /*#__PURE__*/React.createElement("div", {
    className: props.type === 'fields' ? "ahfb-toolbar-inner-paper ahfb-toolbar-field-types" : "ahfb-toolbar-inner-paper",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 51,
      columnNumber: 7
    }
  }, props.children));
}
